@@ -664,7 +664,7 @@ namespace @{namespace}
         static intrusive_ptr<TType> create_command_from_xml(const std::string& payload)
         {
             pugi::xml_document doc;
-            doc.load(payload.c_str());
+            doc.load_string(payload.c_str());
             auto root = doc.root().first_child();
             auto command = shared().build<TType>(root.name());
             if(command != nullptr)
@@ -711,7 +711,7 @@ namespace @{namespace}
         static intrusive_ptr<TType> create_command_from_xml(const std::string& payload)
         {
             pugi::xml_document doc;
-            doc.load(payload.c_str());
+            doc.load_string(payload.c_str());
             auto root = doc.root().first_child();
             auto command = shared().build<TType>(root.name());
             if(command != nullptr)
